#!/usr/bin/env python

import logging
from optparse import OptionParser
import os.path
import sys
import uuid

logging.basicConfig(level=logging.DEBUG)

import boto
import yaml

parser = OptionParser()
parser.add_option("-c", "--config", dest="config",
                  help="Configuration filename",
                  default="./start_instance.yaml")
parser.add_option("", "--no-instance", dest="start_instance",
                  action="store_false", default=True,
                  help="Don't start any instance")
(options, args) = parser.parse_args()

conf = yaml.load(open(options.config))
logging.debug("Configuration: %s" % (conf))

if not conf.has_key('puppet_nodes'):
    logging.error("No puppet nodes defined.")
    sys.exit(1)

try:
    puppet_node = args[0]
except IndexError:
    logging.error("Need puppet node")
    logging.warning("Known nodes %s" % (conf['puppet_nodes'].keys()))
    sys.exit(1)

try:
    node_conf = conf['puppet_nodes'][puppet_node]
except KeyError:
    logging.error("Unknown puppet node %s" % (puppet_node))
    logging.warning("Known nodes %s" % (conf['puppet_nodes'].keys()))
    sys.exit(1)

try:
    ami_id = conf['ami_id']
except KeyError:
    logging.error("Need AMI ID")
    sys.exit(1)

try:
    s3_bucket_name = conf['s3_bucket_name']
except KeyError:
    logging.error("Need S3 bucket name")
    sys.exit(1)

try:
    puppetmaster_server = conf['server']
except KeyError:
    logging.error("Need puppetmaster server dns name")
    sys.exit(1)

try:
    puppetmaster_ca_cert = conf['ca_cert']
except KeyError:
    logging.error("Need puppetmaster CA certificate")
    sys.exit(1)

logging.debug("Starting instance of %s" % (puppet_node))
certname = str(uuid.uuid4())
cloud_init = node_conf['cloud_init']
try:
    cloud_init['puppet']['conf']['agent']['certname'] = certname
except KeyError, e:
    logging.error("Unable to update cloud_init configuration with certname")
    raise e
logging.debug("cloud_init: %s" % (cloud_init))

ec2_conn = boto.connect_ec2()
ami = ec2_conn.get_all_images(ami_id)[0]
s3_conn = boto.connect_s3()
bucket = s3_conn.create_bucket(s3_bucket_name)
bucket.set_acl('public-read')
k = boto.s3.key.Key(bucket)
run_args = { "user_data" : "#cloud-config\n%s" % (yaml.dump(cloud_init)) }
logging.debug("Args: %s" % (run_args))
logging.debug("Node conf: %s" % (node_conf))
if options.start_instance:
    logging.debug("Starting instance of ami %s" % (ami))
    reservation = ami.run(**run_args)
    logging.debug("Publishing instance %s to bucket" % (certname))
    external_node = None
    try:
        external_node = node_conf["external_node"]
    except KeyError:
        logging.info("Puppet external node info not available")
    k.key = certname
    logging.debug("External node: %s" % (external_node))
    k.set_contents_from_string(yaml.dump(external_node))
    k.set_acl('public-read')
