stage { "apt": before => Stage["main"]; }
stage { "hadoop-base": before => Stage["main"], require => Stage["apt"]; }

class hadoop::apt {
    class {
         "apt::apt":
            stage => apt;
    }
    apt::sources_list { 
        "cloudera":
            content => "deb http://archive.cloudera.com/debian/ lucid-cdh3 contrib";
        "canonical":
            content => "deb http://archive.canonical.com/ lucid partner";
    }

    apt::key {
        "cloudera":
    }
}

class hadoop::base {
    class {
         "hadoop::apt":
            stage => apt;
    }
    package {
        "hadoop-0.20":
            ensure => latest,
            require => Package["sun-java6-bin"];
        "sun-java6-bin":
            ensure => latest,
            require  => File["/var/cache/debconf/sun-java6.seeds"],
            responsefile => "/var/cache/debconf/sun-java6.seeds";
    }

    file {
        "/var/cache/debconf/sun-java6.seeds":
            ensure => present,
            source => "puppet:///modules/hadoop/sun-java6.seeds";

        "/etc/default/hadoop-0.20":
            ensure => present,
            source => "puppet:///modules/hadoop/hadoop-0.20.default",
            owner => 'root', group => 'root', mode => 644,
            require => Package["hadoop-0.20"];

        "/etc/hadoop-0.20/conf.puppet":
            ensure => directory,
            owner => 'hadoop', group => 'hadoop', mode => 644,
            require => Package["hadoop-0.20"];


        "/etc/hadoop-0.20/conf.puppet/hdfs-site.xml":
            content => template("hadoop/hdfs-site.xml.erb"),
            owner => 'hadoop', group => 'hadoop', mode => 644,
            require => File["/etc/hadoop-0.20/conf.puppet"];


        "/var/lib/hadoop-0.20/dfs":
            ensure => directory,
            owner => 'hadoop', group => 'hadoop', mode => 644,
            require => Package["hadoop-0.20"]; 

    }

    exec {
        "/usr/sbin/update-alternatives --install /etc/hadoop-0.20/conf hadoop-0.20-conf /etc/hadoop-0.20/conf.puppet 15":
            refreshonly => true,
            require => [Package["hadoop-0.20"],
                        File["/etc/hadoop-0.20/conf.puppet"]],
            subscribe => File["/etc/hadoop-0.20/conf.puppet"];
    }
}

class hadoop::worker {
    class {
         "hadoop::base":
            stage => hadoop-base;
    }
    package {
        [ "hadoop-0.20-tasktracker", "hadoop-0.20-datanode" ]:
            ensure => latest;
    }
    file {
        "/var/lib/hadoop-0.20/dfs/data":
            ensure => directory,
            owner => 'hadoop', group => 'hadoop', mode => 644;
    }
    File <<| title == 'hadoop-core-site' |>>
    File <<| title == 'hadoop-mapred-site' |>>
    service {
        ["hadoop-0.20-tasktracker", "hadoop-0.20-datanode"]:
            hasstatus => true,
            ensure => running,
            enable => true,
            subscribe => [File["hadoop-core-site"],
                          File["hadoop-mapred-site"],
                          File["/etc/hadoop-0.20/conf.puppet/hdfs-site.xml"]],
            require => [Package["hadoop-0.20-tasktracker"],
                        Package["hadoop-0.20-datanode"],
                        File["hadoop-core-site"],
                        File["hadoop-mapred-site"]];
    }
}

class hadoop::jobtracker {
    class {
         "hadoop::base":
            stage => hadoop-base;
    }
    package {
        [ "hadoop-0.20-jobtracker" ]:
            ensure => latest,
            require => Package["hadoop-0.20"];
    }
    @@file {
        "hadoop-mapred-site":
            path => "/etc/hadoop-0.20/conf.puppet/mapred-site.xml",
            content => template("hadoop/mapred-site.xml.erb"),
            owner => 'hadoop', group => 'hadoop', mode => 644;
    }
    File <<| title == 'hadoop-core-site' |>>
    File <<| title == 'hadoop-mapred-site' |>>
    service {
        "hadoop-0.20-jobtracker":
            hasstatus => true,
            ensure => running,
            enable => true,
            subscribe => [File["hadoop-core-site"],
                          File["hadoop-mapred-site"],
                          File["/etc/hadoop-0.20/conf.puppet/hdfs-site.xml"]],
            require => [Package["hadoop-0.20-jobtracker"],
                        File["hadoop-core-site"],
                        File["hadoop-mapred-site"]];
    }
}

class hadoop::namenode {
    class {
         "hadoop::base":
            stage => hadoop-base;
    }
    package {
        [ "hadoop-0.20-namenode" ]:
            ensure => latest;
    }
    file {
        "/var/lib/hadoop-0.20/dfs/name":
            ensure => directory,
            owner => 'hadoop', group => 'hadoop', mode => 644;
    }
    @@file {
        "hadoop-core-site":
            path => "/etc/hadoop-0.20/conf.puppet/core-site.xml",
            content => template("hadoop/core-site.xml.erb"),
            owner => 'hadoop', group => 'hadoop', mode => 644;
    }
    File <<| title == 'hadoop-core-site' |>>
    exec {
        "format-dfs":
            command => "/bin/su hadoop -c 'yes Y | /usr/bin/hadoop --config /etc/hadoop-0.20/conf.puppet namenode -format'",
            refreshonly => true,
            subscribe => File["/var/lib/hadoop-0.20/dfs/name"],
            require => File["/var/lib/hadoop-0.20/dfs/name"],
            creates => "/var/lib/hadoop-0.20/dfs/name/image";
    }
    service {
        "hadoop-0.20-namenode":
            hasstatus => true,
            ensure => running,
            enable => true,
            subscribe => [File["hadoop-core-site"],
                          File["/etc/hadoop-0.20/conf.puppet/hdfs-site.xml"]],
            require => [File["hadoop-core-site"],
                        Package["hadoop-0.20-namenode"],
                        Exec["format-dfs"]];
    }
}
