#!/usr/bin/python

import logging
import logging.handlers
from optparse import OptionParser
import re
import subprocess
import sys
import urllib

handler = logging.handlers.SysLogHandler('/dev/log', 'daemon')
fmt = logging.Formatter('%(filename)s[%(process)d]: %(levelname)s: %(message)s')
handler.setFormatter(fmt)
logging.getLogger().addHandler(handler)

parser = OptionParser()
parser.add_option("", "--log-level", dest="log_level", default="info",
                  help="log level (as defined in python logging module)")
(options, args) = parser.parse_args()
logging.getLogger().setLevel(logging.getLevelName(options.log_level.upper()))

try:
    s3_bucket_url  = args[0]
except IndexError:
    logging.error("Need base S3 bucket URL")
    parser.print_help()
    sys.exit(1)

UUID_RE = re.compile(r"[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}")

try:
    csrs = subprocess.Popen(["puppetca", "--list"], stdout=subprocess.PIPE)\
                     .communicate()[0]
except OSError, e:
    logging.error("Unable to run puppetca list: %s" % (e))
    sys.exit(1)

logging.debug("List of waiting csr: %s" % (csrs))
for certname in csrs.split("\n"):
    if certname == "":
        continue
    if not UUID_RE.match(certname):
        logging.warning("Non-standard csr: %s" % (certname))
        continue
    logging.debug("Checking %s" % (certname))
    u = "%s/%s" % (s3_bucket_url, certname)
    logging.debug("Checking url %s" % (u))
    url = urllib.urlopen(u)
    if url.code == 200:
        logging.info("Signing request: %s" % (certname))
        try:
            subprocess.check_call(["puppetca", "--sign", certname])
        except subprocess.CalledProcessError, e:
            logging.warning("Failed to sign csr (%s): %s" % (certname, e))
    elif url.code == 404:
        logging.warning("Unknown csr: %s" % (certname))
    else:
        logging.warning("Unkown return code for %s: %s" % (certname, url.code)) 
