class puppet::master($is_ca=false, $node_bucket) {
    package { [ "puppetmaster-passenger"]:
                  ensure => latest,
                  require => [Package["libactiverecord-ruby"],
                              Package[ "libsqlite3-ruby"]];
              [ "libactiverecord-ruby", "sqlite3", "libsqlite3-ruby",
                "apache2.2-common" ]:
                  ensure => latest;
    }
    service { "apache2":
                ensure => running,
                enable => true,
                require => Package["puppetmaster-passenger"];
    }
    file { "/etc/apache2/ports.conf":
                ensure => present,
                source => ["/etc/puppet/modules/puppet/files/ports.conf",
                           "puppet:///modules/puppet/ports.conf"],
                mode => 0644,
                owner => root,
                group => root,
                require => Package["apache2.2-common"],
                notify => Service["apache2"];
           "/usr/local/bin/node_classifier":
                content => template("puppet/node_classifier.py"),
                mode => 755,
                owner => root,
                group => root;
           "/etc/puppet/puppet.conf":
                content => template("puppet/puppet.conf"),
                owner => root, group=> root, mode => 644,
                require => Package["puppetmaster-passenger"],
                notify => Service["apache2"];
           "/etc/apache2/sites-available/puppetmaster":
                content => template("puppet/apache2.conf"),
                owner => root, group=> root, mode => 644,
                require => Package["puppetmaster-passenger"],
                notify => Service["apache2"];
    }
}

class puppet::ca($node_bucket) {
    class { "puppet::master": 
               is_ca => true,
               node_bucket => $node_bucket;
    }
    file {
       "/usr/local/bin/check_csr":
           source =>["/etc/puppet/modules/puppet/files/check_csr.py",
                     "puppet:///modules/puppet/check_csr.py"],
           mode => 755,
           owner => root,
           group => root,
    }
    cron { check_csr:
            command => "/usr/local/bin/check_csr $node_bucket",
            user => root,
            minute => '*/2',
            environment => "PATH=/bin:/usr/bin:/usr/sbin",
            require => File['/usr/local/bin/check_csr'],
    } 
}
